﻿#include "DIALOG.h"

/*********************************************************************
*
*       Externals
*
**********************************************************************
*/

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define DIR_RIGHT  0
#define DIR_LEFT   1

/*********************************************************************
*
*       Types
*
**********************************************************************
*/
typedef struct {
  WM_HWIN hWin;
  int     Dir;
  int     xOrg;
  int     yOrg;
  int     xDist;
} ANIM_DATA;

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/

/*********************************************************************
*
*       Static code
*
**********************************************************************
*/
/*********************************************************************
*
*       _cbWin
*/
static void _AnimateWindow(GUI_ANIM_INFO * pInfo, void * pVoid) {
  int xPos;
  ANIM_DATA * pData;

  pData = (ANIM_DATA *)pVoid;

  if (pData->Dir == DIR_RIGHT) {
    xPos = pData->xOrg + (pData->xDist * pInfo->Pos) / GUI_ANIM_RANGE;
  } else {
    xPos = pData->xOrg - (pData->xDist * pInfo->Pos) / GUI_ANIM_RANGE;
  }
  WM_MoveTo(pData->hWin, xPos, pData->yOrg);
}

/*********************************************************************
*
*       _cbWin
*/
static void _cbWin(WM_MESSAGE * pMsg) {
  switch (pMsg->MsgId) {
  case WM_PAINT:
    GUI_SetBkColor(GUI_RED);
    GUI_Clear();
    break;
  default:
    WM_DefaultProc(pMsg);
    break;
  }
}

/*********************************************************************
*
*       _cbBk
*/
static void _cbBk(WM_MESSAGE * pMsg) {
  WM_HWIN                hItem;
  static ANIM_DATA       AnimData;
  static GUI_ANIM_HANDLE hAnim;
  int                    Id;
  int                    NCode;

  switch (pMsg->MsgId) {
  case WM_CREATE:
    hItem = BUTTON_CreateEx(10, LCD_GetYSize() - 30, 80, 20, WM_HBKWIN, WM_CF_SHOW, 0, GUI_ID_BUTTON0);
    BUTTON_SetText(hItem, "Move left");
    hItem = BUTTON_CreateEx(LCD_GetXSize() - 90, LCD_GetYSize() - 30, 80, 20, WM_HBKWIN, WM_CF_SHOW, 0, GUI_ID_BUTTON1);
    BUTTON_SetText(hItem, "Move right");

    AnimData.hWin = WM_CreateWindowAsChild(10, 10, 100, 100, WM_HBKWIN, WM_CF_SHOW, _cbWin, 0);
    AnimData.Dir  = DIR_LEFT;
    AnimData.xOrg = WM_GetWindowOrgX(AnimData.hWin);
    AnimData.yOrg = WM_GetWindowOrgY(AnimData.hWin);
    AnimData.xDist = LCD_GetXSize() - AnimData.xOrg * 2 - WM_GetWindowSizeX(AnimData.hWin);

    break;
  case WM_NOTIFY_PARENT:
    Id    = WM_GetId(pMsg->hWinSrc);
    NCode = pMsg->Data.v;
    switch (Id) {
    case GUI_ID_BUTTON0:
      switch (NCode) {
      case WM_NOTIFICATION_RELEASED:
        if (AnimData.Dir != DIR_LEFT) {
          AnimData.Dir  = DIR_LEFT;
          AnimData.xOrg = WM_GetWindowOrgX(AnimData.hWin);
          hAnim = GUI_ANIM_Create(500, 25, NULL, NULL);
          GUI_ANIM_AddItem(hAnim, 0, 500, ANIM_ACCELDECEL, &AnimData, _AnimateWindow);
          GUI_ANIM_StartEx(hAnim, 1, NULL);
        }
        break;
      }
      break;
    case GUI_ID_BUTTON1:
      switch (NCode) {
      case WM_NOTIFICATION_RELEASED:
        if (AnimData.Dir != DIR_RIGHT) {
          AnimData.Dir  = DIR_RIGHT;
          AnimData.xOrg = WM_GetWindowOrgX(AnimData.hWin);
          hAnim = GUI_ANIM_Create(500, 25, NULL, NULL);
          GUI_ANIM_AddItem(hAnim, 0, 500, ANIM_ACCELDECEL, &AnimData, _AnimateWindow);
          GUI_ANIM_StartEx(hAnim, 1, NULL);
        }
        break;
      }
      break;
    }
    break;
  case WM_PAINT:
    GUI_SetBkColor(GUI_BLACK);
    GUI_Clear();
    break;
  default:
    WM_DefaultProc(pMsg);
    break;
  }
}

/*********************************************************************
*
*       Public code
*
**********************************************************************
*/
/*********************************************************************
*
*       MainTask
*/
void MainTask(void) {
  GUI_Init();
  WM_MULTIBUF_Enable(1);
  WM_SetCallback(WM_HBKWIN, _cbBk);
  WM_SendMessageNoPara(WM_HBKWIN, WM_CREATE);
  while (1) {
    GUI_Delay(100);
  }
}

/*************************** End of file ****************************/
